function [lastkurve] = effektbehov(areal, bygningskategori, tappevann)

%Innlasting av koeffisienter for aktuell bygningskategori
if bygningskategori == 1
    load OB.mat A_wd B_wd A_we B_we HTW_wd HTW_we CPT_wd CPT_we SLI_wd SLI_we;
elseif bygningskategori == 2
    load AB.mat A_wd B_wd A_we B_we HTW_wd HTW_we CPT_wd CPT_we SLI_wd SLI_we;
elseif bygningskategori == 3
    load EB1.mat A_wd B_wd A_we B_we HTW_wd HTW_we CPT_wd CPT_we SLI_wd SLI_we;
elseif bygningskategori == 4
    load EB2.mat A_wd B_wd A_we B_we HTW_wd HTW_we CPT_wd CPT_we SLI_wd SLI_we;
elseif bygningskategori == 5
    load HB.mat A_wd B_wd A_we B_we HTW_wd HTW_we CPT_wd CPT_we SLI_wd SLI_we;
elseif bygningskategori == 6
    load HR.mat A_wd B_wd A_we B_we HTW_wd HTW_we CPT_wd CPT_we SLI_wd SLI_we;
end

%Laster inn inndata fra filer
load DRY_dognmiddel.mat dognmiddel;
load aar.mat aar;      %aar er en vektor for alle dager i ret, der 0 = WD og 1 = WE og helligdager

%HCI for ulike bygningskategoriene
HCI_OB = 100;
HCI_AB = 116;
HCI_EB1 = 109;
HCI_EB2 = 103;
HCI_HB = 152;
HCI_HR = 113;

%Beregninger
hour = zeros(24,365); %Initialiserer en vektor for lagring av alle time verdier

for i = 1:length(aar)
    if aar(i) == 0    %Kontrollerer om det er en ukedag eller helligdag
        if i > 128 & i <= 260 & tappevann == 2  %Avslutning og start av fyringssesong for Oslo-klima
            wd = 0;
        else
            if dognmiddel(i) > CPT_wd     %Hvis dgnmiddel er over CPT er oppvarmingbehovet uavhengig av utetemp.
                wd = HTW_wd * SLI_wd; %Effektbehov er gitt av tappevannsbehov
            else
                wd = A_wd + (B_wd.*dognmiddel(i)) ; % Regner ut relativt effektbehov
                wd = wd * SLI_wd; 
            end
        hour(:,i) = wd;  % Lagrer alle timesverdiene for beregnet dgn
        end
    else
        if i > 128 & i <= 260 & tappevann == 2 %Avslutning og start av fyringssesong for Oslo-klima
            we = 0;
        else
            if dognmiddel(i) > CPT_we
                we = HTW_we * SLI_we;
            else
                we = A_we + (B_we.*dognmiddel(i));
                we = we * SLI_we;
            end
        end
        hour(:,i) = we;
    end
end

relativ_lastkurve = reshape(hour,1,8760); %Gjr om matrisen til en vektor for enklere plotting
faktor = SLI_wd/max(relativ_lastkurve); %Relaterer effektbehov til 1
spesifikk_lastkurve = relativ_lastkurve * faktor;
spesifikk_varighetskurve = sort(spesifikk_lastkurve,'descend');
lastkurve = spesifikk_lastkurve * (areal/1000);
varighetskurve = spesifikk_varighetskurve * areal/1000;

%%%% Justering av lastkurven %%%%
yearly_mean_load = sum(spesifikk_lastkurve)/8760;

if bygningskategori == 1
    yearly_mean_load_OB = (HCI_OB * 1000)/8760;
    faktor = yearly_mean_load_OB / yearly_mean_load;
    lastkurve = lastkurve * faktor;
elseif bygningskategori == 2
    yearly_mean_load_AB = (HCI_AB * 1000)/8760;
    faktor = yearly_mean_load_AB / yearly_mean_load;
    lastkurve = lastkurve * faktor;
elseif bygningskategori == 3
    yearly_mean_load_EB1 = (HCI_EB1 * 1000)/8760;
    faktor = yearly_mean_load_EB1 / yearly_mean_load;
    lastkurve = lastkurve * faktor;
elseif bygningskategori == 4
    yearly_mean_load_EB2 = (HCI_EB2 * 1000)/8760;
    faktor = yearly_mean_load_EB2 / yearly_mean_load;
    lastkurve = lastkurve * faktor;
elseif bygningskategori == 5
    yearly_mean_load_HB = (HCI_HB * 1000)/8760;
    faktor = yearly_mean_load_HB / yearly_mean_load;
    lastkurve = lastkurve * faktor;
elseif bygningskategori == 6
    yearly_mean_load_HR = (HCI_HR * 1000)/8760;
    faktor = yearly_mean_load_HR / yearly_mean_load;
    lastkurve = lastkurve * faktor;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%Plotting%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%plot(relativ_lastkurve)
%xlabel('Time')
%ylabel('Varmelast [W/m2]')
%title('Spesifikt lastprofil for kontorbygning med DRY Oslo')
%axis([1 8760 0 60])
%grid on
%hold on

%plot(spesifikk_varighetskurve,'LineWidth',2)
%xlabel('Time')
%ylabel('Varmelast [W/m2]')
%title('Varighetsdiagram for kontorbygning med DRY Oslo')
%axis([1 8760 0 70])
%grid on

%figure(1)
%plot(lastkurve)
%xlabel('Time [h]')
%ylabel('Varmelast [kWh/h]')
%title('Beregnet lastprofil for bygning(er)')
%axis([1 8760 0 max(lastkurve)])
%grid on
%pause
%close(figure(1))

%hold on
%plot(varighetskurve,'LineWidth',2)
%plot(1:1:670,204.7,'r-','LineWidth',3 )
%xlabel('Time [h]')
%ylabel('Varmelast [kWh/h]')
%title('Beregnet varighetsdiagram for kontorbygning p 6500m2 med beliggenhet i Oslo')
%axis([1 8760 0 400])
%grid on