function [ident] = modulerende_olje(ident, kjelnr, energipris)
clc

disp('----  Modulerende oljekjel  ----')
fprintf(1, '\n')

Pinst = input('Skriv inn nominell ytelse for kjelen [kW]\n');
Pmin = input('Skriv inn minste modulerbare ytelse for kjelen [%]\n');
Trg_Qmin = input('Skriv inn rykgasstemperatur ved laveste ytelse [grader C]\n');
Trg_Qmid = input('Skriv inn rykgasstemperatur ved halv ytelse [grader C]\n');
Trg_Qmax = input('Skriv inn rykgasstemperatur ved hyeste ytelse [grader C]\n');
CO2_Qmin = input('CO2 i rykgass ved laveste ytelse [vol% trr rykgass]\n');
CO2_Qmid = input('CO2 i rykgass ved halv ytelse [vol% trr rykgass]\n');
CO2_Qmax = input('CO2 i rykgass ved hyeste ytelse [vol% trr rykgass]\n');
a_str = input('Strlingstap ved nominell ytelse [%]\n');
Imax = input('Skriv maksimal intermittensgrad for kjelen [-]\n');

Pmax = 100;
Trg = [Trg_Qmin Trg_Qmid Trg_Qmax];
CO2 = [CO2_Qmin CO2_Qmid CO2_Qmax];
Pmid = (Pmin + Pmax) / 2;
ytelse = [Pmin Pmid Pmax];
p_CO2 = polyfit(ytelse,CO2,2);
p_Trg = polyfit(ytelse,Trg,2);

%%%%  Test av kurvetilpasning  %%%%
%x = 30:1:100;
%y = polyval(p_Trg,x);
%y2 = polyval(p_CO2,x);

%plot(ytelse,Trg,'r^',x,y)
%axis([0 100 0 200])

%%%% Virkningsgradsberegning  %%%%
K = 0.6;     %Koeffisient ved fyring med olje
Tamb = 20;   %Omgivelsestemp. i grader celsius
ytelse = [Pmin:1:Pmax]; %Ytelsesomrde for kjelen

for i = 1:length(ytelse);
qrok(i) = K * (polyval(p_Trg,ytelse(i)) - Tamb)/(polyval(p_CO2,ytelse(i))); 
qstr(i) = 100 * a_str/ytelse(i);
end

virkn = zeros(1,i);
virkn = 100 - qrok - qstr;

%INTERMITTENT DEL
siste_element = length(virkn);
Pmax = Pinst;
reell_ytelse = (ytelse./100) * Pmax;
Pinst_int = reell_ytelse(1)/(virkn(1)/100);
Pmax_int = reell_ytelse(1);
Pout = 0.1:0.1:Pmax_int;

for i = 1:length(Pout)
    N(i) = Pmax_int/Pout(i);
    I(i) = (N(i)-1)/((N(i)/Imax)+1);
    virk_int(i) = Pout(i)/Pinst_int*(I(i)+1);
end

%Beregning av koeffisientenei kostnadskurven for kjelen
a  = (1/(Imax+1))*Pmax_int;
y1 = Pout(50)/virk_int(50);
y2 = Pout(150)/virk_int(150);
b = (y2 - y1)/(Pout(150)-Pout(50));

%%%% Kostnadskurve %%%%
energipris_olje = energipris(2);
kostnad = (reell_ytelse./(virkn/100)) * energipris_olje;
p = polyfit(reell_ytelse,kostnad,3);

%%%% Lagring i identifikatormatrise %%%%
ident(kjelnr,3) = Pinst;
ident(kjelnr,4) = virkn(siste_element)/100; %Maks ytelse og maks virkningsgrad trenger ikke sammenfalle for en modulerende kjel
ident(kjelnr,7:10) = p;
ident(kjelnr,5) = a;
ident(kjelnr,6) = b;
ident(kjelnr,11) = reell_ytelse(1);

%%%%  Plotting  %%%%
figure(1)
hold on
plot(ytelse/100 * Pinst,virkn)
plot(Pout, virk_int*100)
xlabel('Kjelytelse [kWh/h]')
ylabel('Virkningsgrad [%]')
title('Modulerende oljekjel')
axis([0 Pinst 0 100])
grid on
hold off
pause
close(figure(1))
